==> kie-wb-distributions-7.4.1.Final-project-sources.tar.gz: kie-wb-distributions-7.4.1.Final/kie-drools-wb-parent/kie-drools-wb-home-page-product/src/main/java/org/kie/workbench/drools/client/resources/i18n/Constants.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.drools.client.resources.i18n;

import org.jboss.errai.ui.shared.api.annotations.TranslationKey;

public class Constants {

    @TranslationKey(defaultValue = "")
    public static final String Heading = "Heading";

    @TranslationKey(defaultValue = "")
    public static final String SubHeading = "SubHeading";

    @TranslationKey(defaultValue = "")
    public static final String Design = "Design";

    @TranslationKey(defaultValue = "")
    public static final String DesignDescription = "DesignDescription";

    @TranslationKey(defaultValue = "")
    public static final String DevOps = "DevOps";

    @TranslationKey(defaultValue = "")
    public static final String DevOpsDescription1 = "DevOpsDescription1";

    @TranslationKey(defaultValue = "")
    public static final String DevOpsDescription2 = "DevOpsDescription2";

    @TranslationKey(defaultValue = "")
    public static final String Track = "Track";

    @TranslationKey(defaultValue = "")
    public static final String TrackDescription = "TrackDescription";

    @TranslationKey(defaultValue = "")
    public static final String ProductName = "ProductName";

    @TranslationKey(defaultValue = "")
    public static final String License = "License";

    @TranslationKey(defaultValue = "")
    public static final String Projects = "HomeProducer.Projects";

    @TranslationKey(defaultValue = "")
    public static final String Dashboards = "HomeProducer.Dashboards";

    @TranslationKey(defaultValue = "")
    public static final String Deployments = "HomeProducer.Deployments";

    @TranslationKey(defaultValue = "")
    public static final String Servers = "HomeProducer.Servers";

    @TranslationKey(defaultValue = "")
    public static final String BusinessDashboards = "HomeProducer.BusinessDashboards";
}

==> kie-wb-distributions-7.8.0.Final-project-sources.tar.gz: kie-wb-distributions-7.8.0.Final/kie-drools-wb-parent/kie-drools-wb-home-page-product/src/main/java/org/kie/workbench/drools/client/resources/i18n/Constants.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.drools.client.resources.i18n;

import org.jboss.errai.ui.shared.api.annotations.TranslationKey;

public class Constants {

    @TranslationKey(defaultValue = "")
    public static final String Heading = "Heading";

    @TranslationKey(defaultValue = "")
    public static final String SubHeading = "SubHeading";

    @TranslationKey(defaultValue = "")
    public static final String Design = "Design";

    @TranslationKey(defaultValue = "")
    public static final String DesignDescription = "DesignDescription";

    @TranslationKey(defaultValue = "")
    public static final String Deploy = "Deploy";

    @TranslationKey(defaultValue = "")
    public static final String DeployDescription1 = "DeployDescription1";

    @TranslationKey(defaultValue = "")
    public static final String DeployDescription2 = "DeployDescription2";

    @TranslationKey(defaultValue = "")
    public static final String ProductName = "ProductName";

    @TranslationKey(defaultValue = "")
    public static final String License = "License";

    @TranslationKey(defaultValue = "")
    public static final String Projects = "HomeProducer.Projects";

    @TranslationKey(defaultValue = "")
    public static final String Provisioning = "HomeProducer.Provisioning";

    @TranslationKey(defaultValue = "")
    public static final String Servers = "HomeProducer.Servers";
}
